==> gimp-3.0.6.tar.xz: gimp-3.0.6/app/widgets/gimpdynamicseditor.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995-1999 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_DYNAMICS_EDITOR_H__
#define __GIMP_DYNAMICS_EDITOR_H__


#include "gimpdataeditor.h"


#define GIMP_TYPE_DYNAMICS_EDITOR            (gimp_dynamics_editor_get_type ())
#define GIMP_DYNAMICS_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditor))
#define GIMP_DYNAMICS_EDITOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditorClass))
#define GIMP_IS_DYNAMICS_EDITOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DYNAMICS_EDITOR))
#define GIMP_IS_DYNAMICS_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DYNAMICS_EDITOR))
#define GIMP_DYNAMICS_EDITOR_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditorClass))


typedef struct _GimpDynamicsEditorClass GimpDynamicsEditorClass;

struct _GimpDynamicsEditor
{
  GimpDataEditor  parent_instance;

  GimpDynamics   *dynamics_model;

  GtkWidget      *view_selector;
  GtkWidget      *notebook;
};

struct _GimpDynamicsEditorClass
{
  GimpDataEditorClass  parent_class;
};


GType       gimp_dynamics_editor_get_type (void) G_GNUC_CONST;

GtkWidget * gimp_dynamics_editor_new      (GimpContext      *context,
                                           GimpMenuFactory  *menu_factory);


#endif /* __GIMP_DYNAMICS_EDITOR_H__ */

==> gimp-3.1.4.tar.xz: gimp-3.1.4/app/widgets/gimpdynamicseditor.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995-1999 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#pragma once

#include "gimpdataeditor.h"


#define GIMP_TYPE_DYNAMICS_EDITOR            (gimp_dynamics_editor_get_type ())
#define GIMP_DYNAMICS_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditor))
#define GIMP_DYNAMICS_EDITOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditorClass))
#define GIMP_IS_DYNAMICS_EDITOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_DYNAMICS_EDITOR))
#define GIMP_IS_DYNAMICS_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_DYNAMICS_EDITOR))
#define GIMP_DYNAMICS_EDITOR_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_DYNAMICS_EDITOR, GimpDynamicsEditorClass))


typedef struct _GimpDynamicsEditorClass GimpDynamicsEditorClass;

struct _GimpDynamicsEditor
{
  GimpDataEditor  parent_instance;

  GimpDynamics   *dynamics_model;

  GtkWidget      *view_selector;
  GtkWidget      *notebook;
};

struct _GimpDynamicsEditorClass
{
  GimpDataEditorClass  parent_class;
};


GType       gimp_dynamics_editor_get_type (void) G_GNUC_CONST;

GtkWidget * gimp_dynamics_editor_new      (GimpContext      *context,
                                           GimpMenuFactory  *menu_factory);
